@@ -147,8 +147,8 @@ function(panel.data,	## REQUIRED
 	.sgp.targets <- function(data, cut, convert0.and100) {
 		tmp <- which.min(c(data < cut, FALSE))
 		tmp[tmp==101] <- 100
-			if (convert.0and100) {tmp[tmp==0] <-1; tmp[tmp==100] <- 99}
-				return(tmp)
+		if (convert.0and100) {tmp[tmp==0] <- 1; tmp[tmp==100] <- 99}
+		return(as.integer(tmp))
 	}
 
 	.get.trajectories.and.cuts <- function(percentile.trajectories, trajectories.tf, cuts.tf, projection.unit=projection.unit) {
